@@ -44,7 +44,7 @@ class Tcl_blender(Tcl):
 			event = <QEvent>
 		'''
 		if not event.isAutoRepeat():
-			modifiers = self.sb.app.keyboardModifiers()
+			modifiers = QtWidgets.QApplication.instance().keyboardModifiers()
 
 			if event.key()==self.key_undo and modifiers==QtCore.Qt.ControlModifier:
 				import bpy
@@ -58,7 +58,6 @@ class Tcl_blender(Tcl):
 		:Parameters:
 			event = <QEvent>
 		'''
-
 		Tcl.showEvent(self, event) #super().showEvent(event)
 
 
@@ -67,10 +66,6 @@ class Tcl_blender(Tcl):
 		:Parameters:
 			event = <QEvent>
 		'''
-		if __name__ == "__main__":
-			self.sb.app.quit()
-			sys.exit() #assure that the sys processes are terminated.
-
 		Tcl.hideEvent(self, event) #super().hideEvent(event)
 
 # --------------------------------------------------------------------------------------------
@@ -120,10 +115,12 @@ def show(instanceID=None, *args, **kwargs):
 
 if __name__ == "__main__":
 
-	tcl = Tcl_blender()
-	tcl.show('init')
+	main = Tcl_blender()
+	main.show('init')
 
-	sys.exit(tcl.sb.app.exec_()) # run app, show window, wait for input, then terminate program with a status code returned from app.
+	exit_code = main.app.exec_()
+	if exit_code != -1:
+		sys.exit(exit_code) # run app, show window, wait for input, then terminate program with a status code returned from app.
 
 #module name
 print (__name__)
